@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.9001';
+our $VERSION = '0.9002';
 
 use warnings;
 use strict;
@@ -240,7 +240,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.9001
+version 0.9002
 
 =head1 SYNOPSIS
 
@@ -255,7 +255,7 @@ version 0.9001
       [ 0,0,0,0,0 ], #    "   4      0 "               0
     ]
  );
- $gw->dump();
+ $gw->dump;
 
  my ( $lightest, $heaviest ) = $gw->vertex_span;
  ( $lightest, $heaviest ) = $gw->edge_span;
@@ -285,7 +285,7 @@ of custom weighting.
 
 =head1 METHODS
 
-=head2 new()
+=head2 new
 
   my $gw = Graph::Weighted->new;
 
@@ -293,7 +293,7 @@ Return a new C<Graph::Weighted> object.
 
 Please see L<Graph/Constructors> for the possible constructor arguments.
 
-=head2 populate()
+=head2 populate
 
   $gw->populate($matrix);
   $gw->populate($matrix, $attribute);
@@ -310,9 +310,9 @@ C<Math::MatrixReal> object, or a hashref of edge values.
 Data given as a hash reference may also contain multiple node labels.  Also, the
 keys need not be numeric, just unique.
 
-The optional C<attribute> argument is a string with the default "weight."
+The optional C<attribute> argument is a string with the default C<weight>.
 
-=head2 get_cost()
+=head2 get_cost
 
   $c = $gw->get_cost($vertex);
   $c = $gw->get_cost($vertex, $attribute);
@@ -320,23 +320,23 @@ The optional C<attribute> argument is a string with the default "weight."
   $c = $gw->get_cost(\@edge, $attribute);
 
 Return the named attribute value for the vertex or edge.  If no attribute name
-is given, the string "weight" is used.
+is given, the string C<weight> is used.
 
-=head2 vertex_span()
+=head2 vertex_span
 
- ($lightest, $heaviest) = $gw->vertex_span();
+ ($lightest, $heaviest) = $gw->vertex_span;
  ($lightest, $heaviest) = $gw->vertex_span($attr);
 
 Return the lightest and heaviest vertices as array references.
 
-=head2 edge_span()
+=head2 edge_span
 
- ($lightest, $heaviest) = $gw->edge_span();
+ ($lightest, $heaviest) = $gw->edge_span;
  ($lightest, $heaviest) = $gw->edge_span($attr);
 
 Return the lightest and heaviest edges as array references.
 
-=head2 path_cost()
+=head2 path_cost
 
  $c = $gw->path_cost(\@vertices);
  $c = $gw->path_cost(\@vertices, $attr);
@@ -346,9 +346,9 @@ Return the summed weight (or cost attribute) of the path edges.
 For the cost of the shortest path, please see C<path_length> under
 L<Graph/"All-Pairs Shortest Paths (APSP)">.
 
-=head2 dump()
+=head2 dump
 
-  $gw->dump()
+  $gw->dump
   $gw->dump($attr)
 
 Print out the graph showing vertices, edges and costs.
